@@ -42,7 +42,9 @@ int nw_char='@';
 char *command_name = NULL;
 unsigned char current_sector = 1;
 unsigned char prev_sector = 1;
-char *source_name = NULL;
+char blockBuff[6400];
+int extra_scraps = 0;
+ char *source_name = NULL;
 int source_line = 0;
 int already_warned = 0;
 Name *file_names = NULL;
