@@ -1,6 +1,5 @@
 #include "global.h"
 static int scraps = 1;
-int extra_scraps;
 static void copy_scrap();             /* formats the body of a scrap */
 static void print_scrap_numbers();      /* formats a list of scrap numbers */
 static void format_entry();             /* formats an index entry */
@@ -309,11 +308,9 @@ void write_tex(file_name, tex_name, sector)
                            Arglist *a;
                            Name *name;
                            Arglist * args;
-                           char * * inParams;
                            a = collect_scrap_name(0);
                            name = a->name;
                            args = instance(a->args, NULL, NULL, &changed);
-                           inParams = name->arg;
                            name->mark = TRUE;
                            write_scraps(tex_file, tex_name, name->defs, 0, indent_chars, 0, 0, 1, 0,
                                  args, name->arg, local_parameters, tex_name);
@@ -326,7 +323,7 @@ void write_tex(file_name, tex_name, sector)
                            /* Get label from */
                            char  label_name[MAX_NAME_LEN];
                            char * p = label_name;
-                           while (c = source_get(), c != nw_char) /* Here is 148b-01 */
+                           while (c = source_get(), c != nw_char) /* Here is 150a-01 */
                               *p++ = c;
                            *p = '\0';
                            c = source_get();
@@ -501,7 +498,6 @@ void initialise_delimit_scrap_array() {
 int scrap_type = 0;
 static void write_literal(FILE * tex_file, char * p, int mode)
 {
-   fprintf(tex_file, "", p);
    fputs(delimit_scrap[mode][0], tex_file);
    while (*p!= '\000') {
      if (*p == nw_char)
@@ -562,7 +558,7 @@ static void copy_scrap(file, prefix, name)
                               /* Get label from */
                               char  label_name[MAX_NAME_LEN];
                               char * p = label_name;
-                              while (c = source_get(), c != nw_char) /* Here is 148b-01 */
+                              while (c = source_get(), c != nw_char) /* Here is 150a-01 */
                                  *p++ = c;
                               *p = '\0';
                               c = source_get();
@@ -738,8 +734,6 @@ static void copy_scrap(file, prefix, name)
 }
 void update_delimit_scrap()
 {
-  static int been_here_before = 0;
-
   /* {}-mode begin */
   if (listings_flag) {
     delimit_scrap[0][0][10] = nw_char;
@@ -1002,9 +996,7 @@ static void format_entry(name, tex_file, sector)
      }
   }
 }
-int has_sector(name, sector)
-Name * name;
-unsigned char sector;
+int has_sector(Name * name, unsigned char sector)
 {
   while(name) {
     if (name->sector == sector)
