@@ -131,9 +131,7 @@ static int ambiguous_prefix(node, spelling, sector)
   }
   return FALSE;
 }
-int robs_strcmp(x, y)
-     char *x;
-     char *y;
+int robs_strcmp(char* x, char* y)
 {
    int cmp = 0;
 
