@@ -15,9 +15,14 @@ typedef struct {
   char letter;
   unsigned char sector;
 } ScrapEntry;
-static ScrapEntry *SCRAP[256];
 
-#define scrap_array(i) SCRAP[(i) >> 8][(i) & 255]
+#define SCRAP_BITS 10
+#define SCRAP_SIZE (1<<SCRAP_BITS)
+#define SCRAP_MASK (SCRAP_SIZE - 1)
+#define SCRAP_SHIFT SCRAP_BITS
+static ScrapEntry *SCRAP[SCRAP_SIZE];
+
+#define scrap_array(i) SCRAP[(i) >> SCRAP_SHIFT][(i) & SCRAP_MASK]
 
 static int scraps;
 int num_scraps()
@@ -75,7 +80,7 @@ static int scrap_is_in();
 void init_scraps()
 {
   scraps = 1;
-  SCRAP[0] = (ScrapEntry *) arena_getmem(256 * sizeof(ScrapEntry));
+  SCRAP[0] = (ScrapEntry *) arena_getmem(SCRAP_SIZE * sizeof(ScrapEntry));
 }
 void write_scrap_ref(file, num, first, page)
      FILE *file;
@@ -150,8 +155,8 @@ int collect_scrap()
   /* Create new scrap, managed by \verb|writer| */
   {
     Slab *scrap = (Slab *) arena_getmem(sizeof(Slab));
-    if ((scraps & 255) == 0)
-      SCRAP[scraps >> 8] = (ScrapEntry *) arena_getmem(256 * sizeof(ScrapEntry));
+    if ((scraps & SCRAP_MASK) == 0)
+      SCRAP[scraps >> SCRAP_SHIFT] = (ScrapEntry *) arena_getmem(SCRAP_SIZE * sizeof(ScrapEntry));
     scrap_array(scraps).slab = scrap;
     scrap_array(scraps).file_name = save_string(source_name);
     scrap_array(scraps).file_line = source_line;
@@ -322,7 +327,7 @@ int collect_scrap()
                                /* Get label from */
                                char  label_name[MAX_NAME_LEN];
                                char * p = label_name;
-                               while (c = source_get(), c != nw_char) /* Here is 148b-01 */
+                               while (c = source_get(), c != nw_char) /* Here is 150a-01 */
                                   *p++ = c;
                                *p = '\0';
                                c = source_get();
@@ -448,7 +453,6 @@ static void backup(n, manager)
      int n;
      Manager *manager;
 {
-  Slab *scrap = manager->scrap;
   int index = manager->index;
   if (n > index
       && manager->prev != NULL)
@@ -523,10 +527,12 @@ static Arglist *pop_scrap_name(manager, parameters)
 {
   char name[MAX_NAME_LEN];
   char *p = name;
-  int sector = pop(manager);
-  int c = pop(manager);
   Arglist * args;
+  int c;
 
+  (void)pop(manager); /* not sure why we have to pop twice */
+  c = pop(manager);
+  
   while (c != nw_char) {
     *p++ = c;
     c = pop(manager);
@@ -539,7 +545,6 @@ static Arglist *pop_scrap_name(manager, parameters)
   }
   /* Check for end of scrap name */
   {
-    Name *pn;
     c = pop(manager);
     /* Check for macro parameters */
     
@@ -597,7 +602,6 @@ int write_scraps(file, spelling, defs, global_indent, indent_chars,
   /* This is in file scraps.c */
   int indent = 0;
   int newline = 1;
-  int iter = 0;
   while (defs) {
     /* Copy \verb|defs->scrap| to \verb|file| */
     {
@@ -617,7 +621,7 @@ int write_scraps(file, spelling, defs, global_indent, indent_chars,
           char c2 = pop(&reader);
 
           if (indent_flag && !(c1 == '\n'
-                               || c1 == nw_char && (c2 == '#' || (delayed_indent |= (c2 == '<'))))) {
+                               || (c1 == nw_char && (c2 == '#' || (delayed_indent |= (c2 == '<')))))) {
             /* Put out the indent */
             if (tab_flag)
                 for (indent=0; indent<global_indent; indent++)
@@ -639,7 +643,7 @@ int write_scraps(file, spelling, defs, global_indent, indent_chars,
           char c2 = pop(&reader);
 
           if (indent_flag && !(c1 == '\n'
-                               || c1 == nw_char && (c2 == '#' || (delayed_indent |= (c2 == '<'))))) {
+                               || (c1 == nw_char && (c2 == '#' || (delayed_indent |= (c2 == '<')))))) {
             /* Put out the indent */
             if (tab_flag)
                 for (indent=0; indent<global_indent; indent++)
@@ -668,7 +672,7 @@ int write_scraps(file, spelling, defs, global_indent, indent_chars,
                  char c2 = pop(&reader);
 
                  if (indent_flag && !(c1 == '\n'
-                                      || c1 == nw_char && (c2 == '#' || (delayed_indent |= (c2 == '<'))))) {
+                                      || (c1 == nw_char && (c2 == '#' || (delayed_indent |= (c2 == '<')))))) {
                    /* Put out the indent */
                    if (tab_flag)
                        for (indent=0; indent<global_indent; indent++)
@@ -685,7 +689,7 @@ int write_scraps(file, spelling, defs, global_indent, indent_chars,
              } else {
                /* Don't show newlines in embedded fragmants */
                fputs(". . .", file);
-               return;
+               return 0;
              }
           case '\t': {
                        if (tab_flag)
@@ -807,7 +811,7 @@ int write_scraps(file, spelling, defs, global_indent, indent_chars,
                                   /* Get label from */
                                   char  label_name[MAX_NAME_LEN];
                                   char * p = label_name;
-                                  while (c = pop(&reader), c != nw_char) /* Here is 148b-01 */
+                                  while (c = pop(&reader), c != nw_char) /* Here is 150a-01 */
                                      *p++ = c;
                                   *p = '\0';
                                   c = pop(&reader);
@@ -869,8 +873,7 @@ int write_scraps(file, spelling, defs, global_indent, indent_chars,
                                          putc(' ', file);
                                          write_single_scrap_ref(file, name->defs->scrap);
                                       }
-                                      if (comment_end)
-                                         fputs(comment_end[comment_flag], file);
+                                      fputs(comment_end[comment_flag], file);
                                       putc('\n', file);
                                       if (!delayed_indent)
                                          for (i = indent + global_indent; --i >= 0; )
@@ -932,7 +935,7 @@ int write_scraps(file, spelling, defs, global_indent, indent_chars,
                                    char c2 = pop(&reader);
 
                                    if (indent_flag && !(c1 == '\n'
-                                                        || c1 == nw_char && (c2 == '#' || (delayed_indent |= (c2 == '<'))))) {
+                                                        || (c1 == nw_char && (c2 == '#' || (delayed_indent |= (c2 == '<')))))) {
                                      /* Put out the indent */
                                      if (tab_flag)
                                          for (indent=0; indent<global_indent; indent++)
@@ -1007,8 +1010,7 @@ int write_scraps(file, spelling, defs, global_indent, indent_chars,
                                   putc(' ', file);
                                   write_single_scrap_ref(file, name->defs->scrap);
                                }
-                               if (comment_end)
-                                  fputs(comment_end[comment_flag], file);
+                               fputs(comment_end[comment_flag], file);
                                putc('\n', file);
                                if (!delayed_indent)
                                   for (i = indent + global_indent; --i >= 0; )
@@ -1202,7 +1204,7 @@ typedef struct move_node {
   Goto_Node *state;
   char c;
 } Move_Node;
-static Goto_Node *root[128];
+static Goto_Node *root[256];
 static int max_depth;
 static Goto_Node **depths;
 static Goto_Node *goto_lookup(c, g)
@@ -1344,7 +1346,7 @@ void search()
           if (state)
             s->fail = goto_lookup(a, state);
           else
-            s->fail = root[a];
+            s->fail = root[(unsigned char)a];
           if (s->fail) {
             Name_Node *p = s->fail->output;
             while (p) {
@@ -1380,7 +1382,7 @@ void search()
         if (state)
           state = goto_lookup(c, state);
         else
-          state = root[c];
+          state = root[(unsigned char)c];
         /* Skip over at at */
         if (last == nw_char && c == nw_char)
         {
@@ -1444,11 +1446,11 @@ static void build_gotos(tree)
       int depth = 2;
       char *p = tree->spelling;
       char c = *p++;
-      Goto_Node *q = root[c];
+      Goto_Node *q = root[(unsigned char)c];
       Name_Node * last;
       if (!q) {
         q = (Goto_Node *) arena_getmem(sizeof(Goto_Node));
-        root[c] = q;
+        root[(unsigned char)c] = q;
         q->moves = NULL;
         q->fail = NULL;
         q->moves = NULL;
@@ -1456,7 +1458,7 @@ static void build_gotos(tree)
         q->next = depths[1];
         depths[1] = q;
       }
-      while (c = *p++) {
+      while ((c = *p++)) {
         Goto_Node *new = goto_lookup(c, q);
         if (!new) {
           Move_Node *new_move = (Move_Node *) arena_getmem(sizeof(Move_Node));
@@ -1634,7 +1636,7 @@ static int reject_match(name, post, reader)
   if (sym_char(first) && sym_char(prev)) return TRUE;
   if (op_char(last) && op_char(post)) return TRUE;
   if (op_char(first) && op_char(prev)) return TRUE;
-  return FALSE; /* Here is 148a-01 */
+  return FALSE; /* Here is 149b-01 */
 }
 void
 write_label(char label_name[], FILE * file)
